@@ -77,16 +77,24 @@ class PythonRuntime:
 
     # buffer helper ###########################################################
     def write_representation(self, value):
-        if self.repl.variables.get('pretty_print', True):
-            try:
-                self.repl.write(pformat(value) + '\n')
+        if(self.repl.get_variable('pretty_print') and
+           not isinstance(value, str)):
 
-                return
+            underscore_numbers = self.repl.get_variable('underscore_numbers')
+
+            try:
+                value = pformat(
+                    object=value,
+                    underscore_numbers=underscore_numbers,
+                )
 
             except Exception:
-                pass
+                value = repr(value)
 
-        self.repl.write(repr(value) + '\n')
+        else:
+            value = repr(value)
+
+        self.repl.write(f'{value}\n')
 
     def write_short_description(self, value):
         rows = []
